@@ -14,6 +14,7 @@ from collections import defaultdict
 
 from taipy.core._repository import _FileSystemRepository
 from taipy.core.common import _utils
+from taipy.core.common._utils import Subscriber
 from taipy.core.config.config import Config
 from taipy.core.exceptions.exceptions import NonExistingPipeline, NonExistingTask
 from taipy.core.pipeline._pipeline_model import _PipelineModel
@@ -52,7 +53,10 @@ class _PipelineRepository(_FileSystemRepository[_PipelineModel, Pipeline]):
                 model.tasks,
                 model.id,
                 model.parent_id,
-                {_utils._load_fct(it["fct_module"], it["fct_name"]) for it in model.subscribers},  # type: ignore
+                [
+                    Subscriber(_utils._load_fct(it["fct_module"], it["fct_name"]), it["fct_params"])
+                    for it in model.subscribers
+                ],  # type: ignore
             )
             return pipeline
         except NonExistingTask as err:
